@@ -1,7 +1,7 @@
 package Khonsu;
 use strict;
 use warnings;
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 use PDF::API2;
 
 use Khonsu::File;
@@ -13,7 +13,8 @@ sub new {
 		pages => [],
 		page_size => $args{page_size} || 'A4',
 		page_args => $args{page_args} || {},
-		pdf => PDF::API2->new( -file => sprintf("%s.pdf", $name) )
+		pdf => PDF::API2->new( -file => sprintf("%s.pdf", $name) ),
+		configure => $args{configure}
 	);
 	return $file;
 }
@@ -24,7 +25,7 @@ sub open { ... }
 
 =head1 NAME
 
-Khonsu - The great new Khonsu!
+Khonsu - PDF Generation!
 
 =head1 VERSION
 
@@ -47,29 +48,88 @@ Perhaps a little code snippet.
 
 	use Khonsu;
 
+	my $padding = 20;
+	my $page_padding = $padding * 2;
 	my $khonsu = Khonsu->new(
 		'Ra',
 		page_size => 'A4',
 		page_args => {
-			background => '#36b636'
+			background => '#3ff'
+		},
+		configure => {
+			page_header => {
+				padding => $padding,
+				show_page_num => 'right',
+				page_num_text => 'page {num}',
+				h => $padding,
+				cb => sub {
+					my ($self, $file, %atts) = @_;
+					$self->add(
+						$file,
+						text => 'Ra',
+						align => 'center',
+						%attrs,
+					);
+				}
+			},
+			page_footer => {
+				padding => $padding,
+				show_page_num => 'left',
+				page_num_text => 'page {num}',
+				h => $padding,
+				cb => sub {
+					my ($self, $file, %atts) = @_;
+					$self->add(
+						$file,
+						text => 'Ra',
+						align => 'center',
+						%attrs,
+					);
+				}
+			},
+			toc => {
+				title => 'Table of contents',
+				title_font_args => {
+					size => 50,
+				},
+				title_padding => 10,
+				font_args => {
+					size => 20,
+				},
+				padding => 5,
+			},
+			h1 => {
+				font => { colour => '#0EE' }
+			}
 		}
-	)->add_page;
+	);
 
-	my $padding = 20;
-	my $page_padding = $padding * 2;
-	$khonsu->add_h1(
-		text => $generate_text->(3),
-		x => 20,
+	$khonsu->add_image(
+		image => 't/test.png',
+		x => $padding,
 		y => $padding,
 		w => $khonsu->page->w - $page_padding,
-		font => {
-			colour => '#fff'
-		}
+		h => $khonsu->page->h - $page_padding,
+	)->add_page;
+
+	$khonsu->add_toc(
+		x => $padding,
+		y => $padding,
+		w => $khonsu->page->w - $page_padding,
+		h => $khonsu->page->h - $page_padding
+	);
+
+	$khonsu->add_h1(
+		text => $generate_text->(3),
+		x => $padding,
+		y => $padding,
+		w => $khonsu->page->w - $page_padding,
+		toc => 1,
 	)->add_text(
 		text => $generate_text->(2000),
-		x => 20,
-		y => ($padding * 2) + $khonsu->h1->line_height,
-		w => $khonsu->page->w - 40,
+		x => $padding,
+		y => ($page_padding) + $khonsu->h1->line_height,
+		w => $khonsu->page->w - $page_padding,
 		h => $khonsu->page->h - ($khonsu->h1->line_height + $page_padding + $padding),
 		indent => 4,
 		font => {
@@ -77,20 +137,9 @@ Perhaps a little code snippet.
 		},
 		overflow => 1,
 	);
-
-	$khonsu->add_page(
-		background => '#fff'
-	)->add_image(
-		image => 't/test.png',
-		x => 20,
-		y => 20,
-		w => $khonsu->page->w - 40,
-		h => $khonsu->page->h - 40,
-	);
-
+	
 	$khonsu->save();
 
-
 =head1 AUTHOR
 
 LNATION, C<< <email at lnation.org> >>
