@@ -3,6 +3,8 @@ package Khonsu::Ra;
 use strict;
 use warnings;
 
+use Clone;
+
 use Khonsu::Shape::Line;
 use Khonsu::Shape::Box;
 use Khonsu::Shape::Circle;
@@ -21,6 +23,10 @@ use Khonsu::Text::H6;
 
 use Khonsu::Image;
 
+use Khonsu::Form;
+use Khonsu::Form::Field::Input;
+
+
 use Khonsu::TOC;
 
 use Types::Standard qw/Str Object ArrayRef HashRef Num Bool CodeRef/;
@@ -87,6 +93,13 @@ use constant IMAGE => (
 use constant TOC => (
 	toc => {is => 'rw', isa => Object, default => sub { Khonsu::TOC->new() }}
 );
+use constant FORM => (
+	form => {is => 'rw', isa => Object, default => sub { Khonsu::Form->new() }}
+);
+use constant INPUT => (
+	input => {is => 'rw', isa => Object, default => sub { Khonsu::Form::Field::Input->new() }}
+);
+
 sub new {
 	my ($pkg, %params) = @_;
 
@@ -156,6 +169,12 @@ sub set_attributes {
 	return $self;
 }
 
+sub clone {
+	my ($self) = @_;
+	my $ref = ref $self;
+	return bless Clone::clone($self), $ref;
+}
+
 sub DESTROY {}
 
 sub AUTOLOAD {
