@@ -11,6 +11,7 @@ sub attributes {
 		pad => {$a->RW, $a->STR},
 		pad_end => {$a->RW, $a->STR},
 		align => {$a->RW, $a->STR, default => sub { 'left' }},
+		end_w => {$a->RW, $a->NUM},
 		$a->FONT,
 		$a->POINTS
 	);
@@ -63,6 +64,7 @@ sub add {
 			$word = shift @words;
 			$width += $text->advancewidth($word);
 		}
+		$self->end_w($xpos + $width);
 		if ($word) {
 			unshift @words, $word if (scalar @words);
 		} elsif ($self->pad) {
